@@ -22,11 +22,11 @@ VSGDR::MergeData - Static data script support package for SSDT post-deployment s
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 sub databaseName {
@@ -104,6 +104,7 @@ sub generateScript {
     my $src_table                       = shift ;
     my $targ_schema                     = shift ;
     my $targ_table                      = shift ;
+    my $script_type                     = shift ;
 
     croak "bad arg dbh"                 unless defined $dbh;
     croak "bad arg source schema"       unless defined $src_schema;
@@ -164,9 +165,11 @@ sub generateScript {
     my $valuesclause    = "(" . do {local $" = ", "; "@{[map {\"src.[$_->[0]]\"} @$ra_columns]}" } . ") ";
 
     my $fullUpdateClause = "" ;
+    my $exceptClause  = "select "         . do {local $" = ", "; "@{[map {\"tgt.[$_->[0]]\"} @nonKeyColumns]}" };
+       $exceptClause .= " except select " . do {local $" = ", "; "@{[map {\"src.[$_->[0]]\"} @nonKeyColumns]}" };
     
     if ( scalar @nonKeyColumns > 0 ) {
-        $fullUpdateClause =  "when matched then update\n    set     " . do {local $" = "\n    ,       "; "@{[map {\"tgt.[$_->[0]]\t\t=  src.[$_->[0]]\"} @nonKeyColumns]}" };
+        $fullUpdateClause ="when matched and exists (select * from (${exceptClause}) x )\n    then update\n    set     " . do {local $" = "\n    ,       "; "@{[map {\"tgt.[$_->[0]]\t\t=  src.[$_->[0]]\"} @nonKeyColumns]}" };
     }
 
     my $maxCol;
